==> google-cloud-apigee-connect-1.0.0.tar.gz: google-cloud-apigee-connect-1.0.0/google/cloud/apigeeconnect_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.connection_service import ConnectionServiceClient
from .services.connection_service import ConnectionServiceAsyncClient
from .services.tether import TetherClient
from .services.tether import TetherAsyncClient

from .types.connection import Cluster
from .types.connection import Connection
from .types.connection import ListConnectionsRequest
from .types.connection import ListConnectionsResponse
from .types.tether import EgressRequest
from .types.tether import EgressResponse
from .types.tether import Header
from .types.tether import HttpRequest
from .types.tether import HttpResponse
from .types.tether import Payload
from .types.tether import StreamInfo
from .types.tether import Url
from .types.tether import Action
from .types.tether import Scheme
from .types.tether import TetherEndpoint

__all__ = (
    "ConnectionServiceAsyncClient",
    "TetherAsyncClient",
    "Action",
    "Cluster",
    "Connection",
    "ConnectionServiceClient",
    "EgressRequest",
    "EgressResponse",
    "Header",
    "HttpRequest",
    "HttpResponse",
    "ListConnectionsRequest",
    "ListConnectionsResponse",
    "Payload",
    "Scheme",
    "StreamInfo",
    "TetherClient",
    "TetherEndpoint",
    "Url",
)

==> google-cloud-apigee-connect-1.7.0.tar.gz: google-cloud-apigee-connect-1.7.0/google/cloud/apigeeconnect_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.apigeeconnect import gapic_version as package_version

__version__ = package_version.__version__


from .services.connection_service import (
    ConnectionServiceAsyncClient,
    ConnectionServiceClient,
)
from .services.tether import TetherAsyncClient, TetherClient
from .types.connection import (
    Cluster,
    Connection,
    ListConnectionsRequest,
    ListConnectionsResponse,
)
from .types.tether import (
    Action,
    EgressRequest,
    EgressResponse,
    Header,
    HttpRequest,
    HttpResponse,
    Payload,
    Scheme,
    StreamInfo,
    TetherEndpoint,
    Url,
)

__all__ = (
    "ConnectionServiceAsyncClient",
    "TetherAsyncClient",
    "Action",
    "Cluster",
    "Connection",
    "ConnectionServiceClient",
    "EgressRequest",
    "EgressResponse",
    "Header",
    "HttpRequest",
    "HttpResponse",
    "ListConnectionsRequest",
    "ListConnectionsResponse",
    "Payload",
    "Scheme",
    "StreamInfo",
    "TetherClient",
    "TetherEndpoint",
    "Url",
)
